.dropdown_hint {
    right: 2em;
    display: none;
    position: absolute;
    min-width: 5em;
    text-align: right;
    white-space: nowrap;

    direction: rtl;
    unicode-bidi: bidi-override;
    cursor: pointer;
}

.conspect_name {
    padding-left: 1em;
}

.gray_text {
    color: gray;
}

.progress-bar {
    color: black;
}

#conspect_subconspect_typeahead .tt-menu {
    max-height: 20em;
    overflow-y: auto;
}

body {
    width: 100%;
    margin: 0;
}

#whole_conspect_subconspect {
    display: none;
}

.btn-default {
    width: 5em;
}

.kw_remover {
    color: red;
    cursor: pointer;
}

/*.kw_enum {
    list-style-type: none;
}*/

.whole_keyword_list {
    margin-bottom: 1em;
}

.kw_list ol {
    padding-left: 0;
    list-style: none;
}

.help_placeholder {
    display: none;
}

#black_overlay {
    display: none;
    position: absolute;
    top: 0%;
    left: 0%;
    width: 100%;
    height: 300%;
    background-color: black;
    z-index: 1001;
    -moz-opacity: 0.8;
    opacity:.80;
    filter: alpha(opacity=80);
}

#log_placeholder, #output_picker, #help_overlay {
    display: none;
    position: fixed;
    top: 10%;
    left: 15%;
    width: 70%;
    height: 80%;
    border: 1px solid gray;
    z-index: 1003;
    overflow: auto;
    background-color: white;
}

#author_picker {
    display: none;
    position: fixed;

    top: 10%;
    left: 50%;
    transform: translateX(-43%);

    width: 60em;
    height: auto;

    border: 1px solid gray;
    z-index: 1003;
    overflow: auto;
    background-color: white;

    padding-right: 3em;
    padding-bottom: 3em;
}

.output_group {
    width: 90%;
    margin: 0;
}

.reversed {
    -ms-transform: rotate(180deg); /* IE 9 */
    -webkit-transform: rotate(180deg); /* Chrome, Safari, Opera */
    transform: rotate(180deg);
    display: inline-block;
}

.glyphicon-question-sign {
    margin-left: 0.2em;
    font-size: 0.8em;
}

.help_iframe {
    width: 100%;
    height: 99.5%;
}

#application_form label {
    font-weight: normal;
}

.required_item {
    font-weight: bold;
}
